@@ -1,17 +1,17 @@
-#!/usr/bin/env perl
+#!/usr/bin/perl
 
 use strict;
 use warnings;
 use NOLookup::Whois::WhoisLookup;
 use Encode;
-use vars qw($opt_q $opt_v $opt_h $opt_s $opt_p);
+use vars qw($opt_q $opt_v $opt_h);
 use Getopt::Std;
 use Pod::Usage;
 
 use Data::Dumper;
 $Data::Dumper::Indent=1;
 
-&getopts('hvq:s:p:');    # q:query, v=verbose dump, s:whois server, p:whois port
+&getopts('hvq:');    # q:query, v=verbose dump
 
 if ($opt_h) {
     pod2usage();
@@ -23,8 +23,8 @@ unless ($opt_q) {
 
 my $q = decode('UTF-8', $opt_q);
 
-my $SERVER = $opt_s || 'whois.norid.no';
-my $PORT   = $opt_p || 43;
+my $SERVER = 'whois.norid.no';
+my $PORT   = 43;
 
 my ($wh, $do, $ho) = NOLookup::Whois::WhoisLookup->new($q, $SERVER, $PORT);
 
@@ -38,42 +38,19 @@ if ($wh->errno) {
 
 #print STDERR "wh: ", Dumper $wh;
 
-if ($do) {
+if ($do && $ho) {
     # Present if a domain name or handle is queried,
     # and a match was found
-    my $hret = "object is";
-
-    print "Domain name      : ", encode('UTF-8', $do->domain_name), "\n";
-    print "Registrar handle : ", $do->registrar_handle, "\n";
-    print "Tech-c handle    : ", $do->tech_c_handle, "\n";
-    foreach my $nh (sort(split("\n", $do->name_server_handle))) {
-	print "Nameserver handle: $nh\n";
-    }
-
-    print "DNSSEC signed    : ";
-    if ($do->dnssec) {
-	print "yes\n";
-    } else {
-	print "no\n";
-    }
     
-    if ($ho) {
-	print "Holder name      : ", encode('UTF-8', $ho->name), "\n";
-	print "Holder address   : ", encode('UTF-8', $ho->post_address), "\n";
-	print "Holder email     : ", encode('UTF-8', $ho->email_address), "\n";
-	print "Id type          : ", encode('UTF-8', $ho->id_type), "\n";
-	print "Id number        : ", encode('UTF-8', $ho->id_number), "\n";
-	if ($ho->organization_type) {
-	    print "Organization type: ", encode('UTF-8', $ho->organization_type), "\n";
-	}
-	$hret = "and holder objects are";
-
-    }
+    print "Domain name   : ", encode('UTF-8', $do->domain_name), "\n";
+    print "Holder name   : ", encode('UTF-8', $ho->name), "\n";
+    print "Holder address: ", encode('UTF-8', $ho->post_address), "\n";
+    
     if ($opt_v) {
 	print "Domain object raw text: ", Dumper($do->raw_text);
-	print "Host object raw text  : ", Dumper($ho->raw_text) if ($ho);
+	print "Host object raw text  : ", Dumper($ho->raw_text);
     } else {
-	print "Domain $hret returned, use -v to see the details\n";
+	print "Domain and holder objects are returned, use -v to see the details\n";
     }
 
 } else {
