@@ -2,7 +2,7 @@ package NOLookup::Whois::WhoisLookup;
 
 use strict;
 use warnings;
-use IO::Socket::INET6;
+use IO::Socket;
 
 use vars qw(@ISA @EXPORT_OK);
 @ISA    = qw( Exporter );
@@ -18,6 +18,8 @@ use vars qw(@ISA @EXPORT_OK);
 
 /;
 
+our $VERSION = 1.01;
+
 # Error codes returned from the WhoisLookup module
 # Ref. the Norid Whois API definition.
 
@@ -79,7 +81,7 @@ sub lookup {
 
     #$client_ip = undef;
     
-    my $sock = IO::Socket::INET6->new (
+    my $sock = IO::Socket::INET->new (
 	PeerAddr => $whois_server,
 	PeerPort => $whois_port,
 	Proto    => 'tcp',
@@ -88,6 +90,7 @@ sub lookup {
 
     unless($sock) {
 	$self->{errno} = $WHOIS_LOOKUP_ERR_NO_CONN;
+	#print STDERR "SOCK ERR: $!\n";
 	return $self;
     }
 
@@ -111,42 +114,37 @@ sub lookup {
     close $sock;
     $text = Encode::decode('UTF-8', $text);
 
-    #print STDERR "text: $text\n";
-    
     # Parse whois and map values into the self object.
     $self->_parse($text);
 
     if ($text =~ m/\nDomain Information\n/) {
-	
-	# If a domain name, or a domain handle, is looked up, the
-	# whois server may also return the holder info as a second
-	# block. The below code parses the domain and holder info and
+	# If a domain name, or a domain handle, is looked up,
+	# the whois server also returns also the holder info as a second block.
+	# The below code parses the domain and holder info and
 	# returns the data in separate objects.
 	#
+
+	#print STDERR "DOMAIN INFO with holder contact info FOUND: $query\n";
 	
-	# Domain info is first block. Holder contact info is second
-	# block, but only if the full (but limited) registrarwhois
-	# service is used. Split the text and make two objects.
+	# Domain info is first block, holder contact info is second block,
+	# split the text and make two objects
 	
 	my ($dmy, $dtxt, $htxt) = split ('NORID Handle', $text);
 
-	my $holder_whois;
 	my $domain_whois = NOLookup::Whois::WhoisLookup->new;
+	my $holder_whois = NOLookup::Whois::WhoisLookup->new;
 
 	#print STDERR "\n------\nparse domain text: '$dtxt'\n";
 	$domain_whois->_parse("\nNORID Handle" . $dtxt);
 
-	if ($htxt) {
-	    $holder_whois = NOLookup::Whois::WhoisLookup->new;
-	    #print STDERR "\n------\nparse holder text: '$htxt'\n";
-	    $holder_whois->_parse("\nNORID Handle" . $htxt);
-	}
+	#print STDERR "\n------\nparse holder text: '$htxt'\n";
+	$holder_whois->_parse("\nNORID Handle" . $htxt);
+	
 	#print STDERR "self  : ", Dumper $self;
 	#print STDERR "domain whois: ", Dumper $domain_whois;
-	#print STDERR "holder whois: ", Dumper $holder_whois if $holder_whois;
+	#print STDERR "holder whois: ", Dumper $holder_whois;
 
 	return $self, $domain_whois, $holder_whois;
-
     } 
 
     if ($text =~ m/\nHosts matching the search parameter\n/) {
@@ -251,10 +249,6 @@ sub TO_JSON {
     $rh;
 }
 
-=pod
-
-=encoding ISO-8859-1
-
 =head1 NAME
 
 NOLookup::Whois::WhoisLookup - Lookup WHOIS data from Norid.
@@ -376,8 +370,7 @@ E<lt>(nospam)info(at)norid.noE<gt>
 
 =head1 SEE ALSO
 
-L<https://www.norid.no/en>
-L<https://teknisk.norid.no/en/integrere-mot-norid/whois>
+L<http://www.norid.no>
 
 =head1 CAVEATS
 
@@ -391,7 +384,7 @@ Trond Haugen, E<lt>(nospam)info(at)norid.noE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2017 Trond Haugen <(nospam)info(at)norid.no>.
+Copyright (c) 2016-2017 Trond Haugen <(nospam)info(at)norid.no>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
